@@ -294,13 +294,14 @@ class Dbaas(object):
     """
 
     def __init__(self, username, api_key, tenant=None, auth_url=None,
-                 service_type='reddwarf', service_name='Reddwarf',
+                 service_type='database', service_name='reddwarf',
                  service_url=None, insecure=False, auth_strategy='keystone',
                  region_name=None, client_cls=ReddwarfHTTPClient):
         from reddwarfclient.versions import Versions
         from reddwarfclient.databases import Databases
         from reddwarfclient.flavors import Flavors
         from reddwarfclient.instances import Instances
+        from reddwarfclient.limits import Limits
         from reddwarfclient.users import Users
         from reddwarfclient.root import Root
         from reddwarfclient.hosts import Hosts
@@ -322,6 +323,7 @@ class Dbaas(object):
         self.databases = Databases(self)
         self.flavors = Flavors(self)
         self.instances = Instances(self)
+        self.limits = Limits(self)
         self.users = Users(self)
         self.root = Root(self)
         self.hosts = Hosts(self)
